@@ -424,7 +424,7 @@ sub CERT_create {
     for(my $i=0;$i<@ext;$i+=2) {
 	$have_ext{ $ext[$i] }++
     }
-    for my $ext (@{ $args{ext} || [] }) {
+    for my $ext (@{ delete $args{ext} || [] }) {
 	my $nid = $ext->{nid}
 	    || $ext->{sn} && Net::SSLeay::OBJ_sn2nid($ext->{sn})
 	    || croak "cannot determine NID of extension";
@@ -444,6 +444,9 @@ sub CERT_create {
 	}
     }
 
+    die "unknown arguments: ". join(" ", sort keys %args) 
+	if !delete $args{ignore_invalid_args} && %args;
+
     Net::SSLeay::X509_set_issuer_name($cert,
 	Net::SSLeay::X509_get_subject_name($issuer_cert));
     Net::SSLeay::X509_sign($cert,$issuer_key,_digest($digest_name));
@@ -783,6 +786,11 @@ given both together.
 
 specify the algorithm used to sign the certificate, default SHA-256.
 
+=item ignore_invalid_args
+
+ignore any unknown arguments which might be in the argument list (which might be
+in the arguments for example as result from CERT_asHash)
+
 =back
 
 =back
